#wrapper {
  display: flex;
  flex-direction: column;
  min-height: 100vh;
}

#page-wrapper {
  display: flex;
  flex-direction: row;
  flex-grow: 1;
}

#page-content {
  background: $white;
  flex-grow: 1;
  padding: 20px;
}

.sidebar {
  background-color: $gray-lightest;
  width: 250px;
  font-size: 14px;
  flex-grow: 0;
  flex-shrink: 0;
  border-right: 1px solid $gray-lighter;
  box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
  z-index: 1;

  li span.has-children {
    display: flex;
    flex-direction: row;
    a {
      flex-grow: 1;
    }
    .arrow {
      flex-grow: 0;
      width: 50px;
      border: none;
      display: flex;
      justify-content: center;
      span {padding-top: 4px;}
    }

  }
  .nav-link, li.nav-fold {
    border-top: 1px solid $gray-light;
  }
  .nav-link {
    padding: 10px 15px;
    &:last-child {
      border-bottom: 1px solid $gray-light;
    }
  }

  .nav-link {
    .fa {
      margin-right: 5px;
    }
    &.nav-link-second-level span {
      padding-left: 1.6em;
    }
  }

  .nav-link.nav-link-second-level, .nav-link.nav-link-inner, .nav-link.nav-link-inner.active {
    border: none;
  }
  .nav-link.active, .nav-link:hover, .nav-link.nav-link-second-level.active, .nav-link.nav-link-second-level:hover {
    background-color: $gray-lighter;
    color: $brand-primary;
  }
}
.navbar {
  color: $brand-primary;
  background-color: $offwhite;
  border-bottom: 4px $brand-primary solid;
  padding: 0.25rem;
  box-shadow: 0 1px 3px rgba(0,0,0,0.12), 0 1px 2px rgba(0,0,0,0.24);
}
.nav-item:hover {
  background-color: $gray-lighter;
}
.navbar-brand img {
  height: 30px;
  width: auto;
  margin: auto;
}
.orga-headline {
  font-weight: bold;
}

.nav-tabs {
  border-bottom: $gray-light solid 1px;
  margin-bottom: 16px;

  .nav-link {
    border: none;
  }
  .nav-link:hover, .nav-link:focus {
    border-bottom: $gray-light solid 2px;
  }
  .nav-link:hover, .nav-link:focus .nav-link.active {
    border-bottom: $brand-primary 2px solid;
    background-color: $white;
  }
  .nav-link.active {
    border-bottom: $brand-primary 4px solid;
  }

}

legend {
  border-bottom: 1px solid #e5e5e5;
  margin-bottom: 20px;
}

footer {
  margin-top: 20px;
  text-align: center;
  font-size: 11px;
}
.feedback-card {
  margin-bottom: 8px;
  .card-body {
    padding: 16px 16px 0px 16px;
  }
}
.question-option-row {
  margin-left: -4px;
  display: flex;
  padding-bottom: 8px;
}
.question-option-input.disabled input {
  background-color: $gray-lighter;
  opacity: 1;
  cursor: not-allowed;
}
.search-form {
  display: flex;
  margin-bottom: 1rem;
  .form-group {
    margin-bottom: 0;
  }
  .form-group label {
    display: none;
  }
  .btn-search {
    height: 100%;
  }
}
.event-logo-field {
  img.event-logo-display {
    margin-left: 12px;
    margin-right: 16px;
    padding: 2px;
    border:1px solid $gray-light;
    max-width: 180px;
  }
}
.bootstrap4-multi-input {
  margin: auto;
}

.fa.override {
  padding-left: 4px;
}
.history-sidebar {
  max-height: 80vh;
  overflow-y: scroll;
  border-bottom: 1px solid rgba(0,0,0,0.125);
}
@include media-breakpoint-down(sm) {
  .container-fluid {
    padding: 0;
    width: 100%;
  }
  .navbar {
    padding: 0.1rem 1rem;

    ul {
      flex-direction: row;
      .fa {
        padding-left: 12px;
      }
    }
  }
  nav.sidebar {
    position: absolute;
    display: none;
  }
  nav.sidebar-uncollapsed {
    display: inherit;
  }
  .history-sidebar {
    display: none;
  }
  #page-content {
    padding: 4px 8px;
    flex-grow: 0;
    width: 100%;
  }
  ul.nav-pills {
    li.nav-item {
      padding: 0;
      margin: 0;
      a {
        padding: 4px 8px;
      }
    }
  }
  .col-form-label {
    text-align: left;
    display: flex;
    span {
      padding-left: 4px;
    }
  }
}

td.reviewer {
  display: flex;
  flex-direction: row;
}

form #id_settings-display_header_pattern {
  display: flex;
  flex-direction: row;
  label {
    padding-right: 16px;
    &:before {
      left: 4px;
      top: 8px;
    }
    &:after {
      left: 8px;
      top: 8px;
    }
  }
  .mini-header {
    width: 100px;
    height: 100px;
    background-color: $brand-primary;
    margin: 0 0 0 -36px;
  }
}
