{% extends "orga/base.html" %}
{% load bootstrap4 %}
{% load i18n %}
{% block content %}

    <form method="post" action="">
        {% csrf_token %}
        <legend>{% trans "Import XML" %}</legend>
        <div class="col-md-9 ml-auto"><p>
        {% blocktrans trimmed %}
        Submit an XML file here to release a new schedule, containing exactly the talks
        specified in the XML file. The format is expected to be the same as the XML
        export provided.
        {% endblocktrans %}
        </p></div>
        {% bootstrap_field form.upload layout='event' %}
        <div class="form-group row">
            <div class="ml-auto col-md-9">
                <button type="submit" class="btn btn-primary">{% trans "Send" %}</button>
            </div>
        </div>
    </form>

{% endblock %}
