{% extends "orga/settings/base.html" %}
{% load bootstrap4 %}
{% load compress %}
{% load i18n %}
{% load staticfiles %}
{% block settings_content %}

<form method="post" action="">
    {% csrf_token %}
    <legend>{% trans "Review settings" %}</legend>
    {% bootstrap_form form layout='event' %}

    <div class="form-group row">
        <div class="ml-auto col-md-9">
            <button type="submit" class="btn btn-primary">{% trans "Save" %}</button>
        </div>
    </div>
</form>

    <span id="vars" remoteUrl="{{ request.event.orga_urls.users }}?search=%QUERY&orga=true"></span>
    {% compress js %}
    <script type="text/javascript" src="{% static "vendored/typeahead.bundle.min.js" %}"></script>
    <script type="text/javascript" src="{% static "orga/js/speakers.js" %}"></script>
    {% endcompress %}
{% endblock %}
